<template>
  <div>
    <div :style="{ borderBottom: '1px solid #E9E9E9',paddingBottom:'8px'}">
      <el-checkbox :indeterminate="indeterminate" v-model="checkAll" @change="handleCheckAllChange">
        全部
      </el-checkbox>
    </div>
    <br />
    <el-checkbox-group class="role-list-wrapper" v-model="valueCheckedAry" @change="handleChange">
      <el-row>
        <el-col :span="8" v-for="item in roleAll" :key="item.id">
          <el-checkbox :label="item.id" :key="item.id">
            {{item.name}}
          </el-checkbox>
        </el-col>
      </el-row>
    </el-checkbox-group>
  </div>
</template>
 
<script>
export default {
  name: "roleSel",
  props: {
    // 显示隐藏
    visible: {
      type: Boolean,
      required: true
    },
    //当前系统用户的所有角色信息
    roleAll: {
      type: Array,
      required: true,
      default: () => {
        return [];
      },
    },
    //选中的ID集合
    checkIdList: {
      type: Array,
      required: true,
      default: () => {
        return [];
      },
    },
    // 全部角色的id集合
    allIdList: {
      type: Array,
      required: true,
      default: () => {
        return [];
      },
    },
    //平台标识
    systemId: {
      type: String,
      required: true,
    }
  },
  data() {
    return {
      // 指定当前是否选中
      checkAll: false,
      // 设置 indeterminate 状态，只负责样式控制: true-显示正方形，false-显示钩或者空（非正方形的）
      indeterminate: false,
      // 选中的角色数组
      valueCheckedAry: [],
    }
  },
  watch: {
    valueCheckedAry: {
      deep: true,
      immediate: true,
      handler(value) {
        this.$emit("updateData", { roleCodes: value, systemId: this.systemId })
      }
    },
    checkIdList: {
      deep: true,
      immediate: true,
      handler(value) {
        // 回显当前角色之前选中的角色
        this.valueCheckedAry = value ? value : [],
          // 去回显样式
          this.handleChange()
      }
    },
    visible(newV) {
      if (!newV) {
        this.restoreSettings();
      }
    }
  },
  methods: {
    /**
     * 全选改变
     */
    handleCheckAllChange(checked) {
      Object.assign(this, {
        valueCheckedAry: checked ? this.allIdList : [],
        indeterminate: false,
        checkAll: checked,
      });
    },
    /**
       * 多选框改变
       * @params:
       * checkedValues：选中的角色
       */
    handleChange() {
      this.indeterminate = !!this.valueCheckedAry.length && this.valueCheckedAry.length < this.roleAll.length;
      if (this.roleAll.length) {
        this.checkAll = this.valueCheckedAry.length === this.roleAll.length;
      }
    },
    /**
     * 还原最初设置
     */
    restoreSettings() {
      this.indeterminate = false
      this.checkAll = false
      this.valueCheckedAry = []
    },
  }
}
</script>

<style>
</style>